.. pyxnat documentation master file, created by sphinx-quickstart on Tue Nov 24 11:04:02 2009.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

pyxnat: Xnat in Python
============================================

.. topic:: **User guide contents:**

 .. toctree::
    :maxdepth: 1

    installing.rst
    under_the_hood.rst
    starters_tutorial.rst
    advanced_tutorial.rst
    reference_documentation.rst

Introduction
------------

.. automodule:: pyxnat

Module contents
----------------

.. currentmodule :: pyxnat

.. autosummary:: 
   :toctree: generated/

    Interface
    Inspector
    Select
    SearchManager
    Users

